@@ -1,5 +1,5 @@
 package QBit::WebInterface::Routing;
-$QBit::WebInterface::Routing::VERSION = '0.009';
+$QBit::WebInterface::Routing::VERSION = '0.010';
 use POSIX qw(strftime setlocale LC_TIME);
 
 use qbit;
@@ -18,7 +18,7 @@ sub import {
 
     die gettext('Use only in QBit::WebInterface and QBit::Application descendant')
       unless $package_wi->isa('QBit::WebInterface')
-          && $package_wi->isa('QBit::Application');
+      && $package_wi->isa('QBit::Application');
 
     {
         no strict 'refs';
@@ -94,7 +94,7 @@ sub build_response {
             };
         } else {
             $path = $route->{'path'} // '';
-            $cmd  = $route->{'cmd'}  // '';
+            $cmd  = $route->{'cmd'} // '';
         }
 
         %params = %{$route->{'args'} // {}};
@@ -217,6 +217,10 @@ QBit::WebInterface::Routing - Class for creating routing for web interface.
 
 https://github.com/QBitFramework/QBit-WebInterface-Routing
 
+=head1 Deprecated
+
+See L<QBit::WebInterface|https://github.com/QBitFramework/QBit-WebInterface>
+
 =head1 Install
 
 =over
@@ -225,10 +229,6 @@ https://github.com/QBitFramework/QBit-WebInterface-Routing
 
 cpanm QBit::WebInterface::Routing
 
-=item *
-
-apt-get install libqbit-webinterface-routing-perl (http://perlhub.ru/)
-
 =back
 
 For more information. please, see code.
